PixelFormat

Struct PixelFormat 

pub struct PixelFormat(/* private fields */);
Four character code (fourcc) defining the encoding of pixel data in an image buffer.

fourcc codes are documented on https://www.fourcc.org/.

Implementations

Source

impl PixelFormat

pub const fn from_fourcc(fourcc: [u8; 4]) -> Self

Creates a PixelFormat from a fourcc code.

pub const fn as_fourcc(self) -> [u8; 4]

Returns the fourcc code represented by self.

Source

impl PixelFormat

Pixel format constants.

pub const BGR3: Self

BGR3 bbbbbbbb gggggggg rrrrrrrr

Same as 24BG.

pub const RGB3: Self

RGB3 rrrrrrrr gggggggg bbbbbbbb

Same as raw .

pub const ABGR32: Self

AR24: bbbbbbbb gggggggg rrrrrrrr aaaaaaaa

pub const XBGR32: Self

XR24: bbbbbbbb gggggggg rrrrrrrr xxxxxxxx

The xxxxxxxx channel data is ignored.

pub const BGRA32: Self

RA24: aaaaaaaa bbbbbbbb gggggggg rrrrrrrr

pub const BGRX32: Self

RX24: xxxxxxxx bbbbbbbb gggggggg rrrrrrrr

pub const RGBA32: Self

AB24: rrrrrrrr gggggggg bbbbbbbb aaaaaaaa

pub const RGBX32: Self

XB24: rrrrrrrr gggggggg bbbbbbbb xxxxxxxx

The xxxxxxxx channel data is ignored.

pub const ARGB32: Self

BA24: aaaaaaaa rrrrrrrr gggggggg bbbbbbbb

pub const XRGB32: Self

BX24: xxxxxxxx rrrrrrrr gggggggg bbbbbbbb

The xxxxxxxx channel data is ignored.

pub const BGR32: Self

BGR4: bbbbbbbb gggggggg rrrrrrrr ???????? DEPRECATED

This format is deprecated because the meaning of the last channel is ill-defined and its interpretation depends on driver and application. It will either be ignored (xxxxxxxx / Self::XBGR32) or treated as an alpha channel (aaaaaaaa / Self::ABGR32), so one of those formats should be used instead if possible.

pub const RGB32: Self

RGB4: ???????? rrrrrrrr gggggggg bbbbbbbb DEPRECATED

This format is deprecated because the meaning of the first channel is ill-defined and its interpretation depends on driver and application. It will either be ignored (xxxxxxxx / Self::XRGB32) or treated as an alpha channel (aaaaaaaa / Self::ARGB32), so one of those formats should be used instead if possible.

pub const YUYV: Self

YUYV: yyyyyyyy uuuuuuuu YYYYYYYY vvvvvvvv

Packed YUV/YCbCr data with 4:2:2 chroma subsampling.

uuuuuuuu and vvvvvvvv are shared by 2 neighboring pixels, while yyyyyyyy is the left pixel’s Y value, and YYYYYYYY is the right pixel’s Y value.

pub const MJPG: Self

MJPG: Motion JPEG, a sequence of JPEG images with omitted huffman tables.

The transmitted JPEG images lack the “DHT” frame (Define Huffman Table), and instead use a predefined one. Most common JPEG decoders will handle this fine and don’t need any extra preprocessing.

pub const JPEG: Self

JPEG: Data is a sequence of regular JFIF JPEG still images.

Images can be decoded with any off-the-shelf JPEG decoder, no preprocessing is needed.

pub const UVC: Self

UVCH: UVC payload header metadata.

Data is a stream of UvcMetadata structures.